==> xld-tasker-extension-10.0.7-sources.jar: com/xebialabs/deployit/task/WorkdirCleanerTrigger.java <==
package com.xebialabs.deployit.task;

import com.xebialabs.deployit.engine.spi.execution.IgnoreOnRollbackExecutionStateListener;
import com.xebialabs.deployit.engine.spi.execution.NonRemotableExecutionStateListener;
import com.xebialabs.deployit.engine.spi.execution.StepExecutionStateEvent;
import com.xebialabs.deployit.engine.spi.execution.TaskExecutionStateEvent;
import com.xebialabs.deployit.repository.WorkDir;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;

@SuppressWarnings("serial")
public class WorkdirCleanerTrigger implements NonRemotableExecutionStateListener, IgnoreOnRollbackExecutionStateListener {

    private List<WorkDir> workDirs = new ArrayList<>();

    private boolean keepWorkdirsIntactOnTaskEnd;

    public WorkdirCleanerTrigger(WorkDir workDir) {
        workDirs.add(workDir);
    }

    public WorkdirCleanerTrigger(List<WorkDir> workDir) {
        for (WorkDir dir : workDir) {
            logger.debug("Registering workdir [{}] for cleanup on task completion.", workDir);
            workDirs.add(dir);
        }
    }

    @Override
    public void stepStateChanged(StepExecutionStateEvent event) {

    }

    @Override
    public void taskStateChanged(TaskExecutionStateEvent event) {
        if (event.currentState().isFinal()) {
            if (!keepWorkdirsIntactOnTaskEnd) {
                logger.info("Cleaning Workdirs [{}] for task [{}]", workDirs, event.task().getId());
                cleanWorkdirs();
            } else {
                logger.info("Workdirs [{}] are kept intact for task [{}]");
            }
        }
    }

    private void cleanWorkdirs() {
        for (WorkDir workDir : workDirs) {
            try {
                workDir.delete();
            } catch (RuntimeException re) {
                logger.error("Failed to clean WorkDir [{}]", workDir);
            }
        }
    }

    public List<WorkDir> getWorkDirs() {
        return workDirs;
    }

    @Override
    public void disable() {
        this.keepWorkdirsIntactOnTaskEnd = true;
    }

    private static final Logger logger = LoggerFactory.getLogger(WorkdirCleanerTrigger.class);
}

==> xld-tasker-extension-2014.10-sources.jar: com/xebialabs/deployit/task/WorkdirCleanerTrigger.java <==
package com.xebialabs.deployit.task;

import com.xebialabs.deployit.engine.spi.execution.ExecutionStateListener;
import com.xebialabs.deployit.engine.spi.execution.StepExecutionStateEvent;
import com.xebialabs.deployit.engine.spi.execution.TaskExecutionStateEvent;
import com.xebialabs.deployit.repository.WorkDir;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

import static com.google.common.collect.Lists.newArrayList;

@SuppressWarnings("serial")
public class WorkdirCleanerTrigger implements ExecutionStateListener {

    private List<WorkDir> workDirs = newArrayList();

    public WorkdirCleanerTrigger(WorkDir workDir) {
        workDirs.add(workDir);
    }

    public WorkdirCleanerTrigger(List<WorkDir> workDir) {
        for (WorkDir dir : workDir) {
            logger.debug("Registering workdir [{}] for cleanup on task completion.", workDir);
            workDirs.add(dir);
        }
    }

    @Override
    public void stepStateChanged(StepExecutionStateEvent event) {

    }

    @Override
    public void taskStateChanged(TaskExecutionStateEvent event) {
        if (event.currentState().isFinal()) {
            logger.info("Cleaning Workdirs [{}] for task [{}]", workDirs, event.task().getId());
            cleanWorkdirs();
        }
    }

    private void cleanWorkdirs() {
        for (WorkDir workDir : workDirs) {
            try {
                workDir.delete();
            } catch (RuntimeException re) {
                logger.error("Failed to clean WorkDir [{}]", workDir);
            }
        }
    }

    public List<WorkDir> getWorkDirs() {
        return workDirs;
    }

    private static final Logger logger = LoggerFactory.getLogger(WorkdirCleanerTrigger.class);
}
